@@ -3,13 +3,13 @@ from tomlkit import loads
 
 
 def test_write_backslash():
-    d = {"foo": "\\e\u25E6\r"}
+    d = {"foo": "\\e\u25e6\r"}
 
-    expected = """foo = "\\\\e\u25E6\\r"
+    expected = """foo = "\\\\e\u25e6\\r"
 """
 
     assert expected == dumps(d)
-    assert loads(dumps(d))["foo"] == "\\e\u25E6\r"
+    assert loads(dumps(d))["foo"] == "\\e\u25e6\r"
 
 
 def test_escape_special_characters_in_key():
